FilterMode

Enum FilterMode 

#[repr(i32)]
pub enum FilterMode { Global = 0, Host = 1, Session = 2, Directory = 3, Workspace = 4, SessionPreload = 5, }

Variants



Global = 0



Host = 1



Session = 2



Directory = 3



Workspace = 4



SessionPreload = 5

Implementations

Source

impl FilterMode

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of FilterMode.

pub fn from_i32(value: i32) -> Option<FilterMode>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a FilterMode, or None if value is not a valid variant.

Source

impl FilterMode

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.